ImageCollection
===============

.. currentmodule:: toasty.collection

.. autoclass:: ImageCollection
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~ImageCollection.descriptions
      ~ImageCollection.export_simple
      ~ImageCollection.images

   .. rubric:: Methods Documentation

   .. automethod:: descriptions
   .. automethod:: export_simple
   .. automethod:: images
